@@ -15,12 +15,14 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
 #ifndef _LOCALS_H_
 #define _LOCALS_H_
 
+#include "plugin.h"
+
 #include <libanjuta/interfaces/ianjuta-debugger.h>
 #include <libanjuta/anjuta-plugin.h>
 
@@ -28,7 +30,7 @@
 
 typedef struct _Locals Locals;
 
-Locals *locals_new (AnjutaPlugin* plugin, IAnjutaDebugger* debugger);
+Locals *locals_new (DebugManagerPlugin *plugin);
 void locals_free (Locals *l);
 
 #endif
