@@ -15,7 +15,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 #ifndef __DEBUGGER_H__
 #define __DEBUGGER_H__
@@ -92,14 +92,14 @@ gboolean debugger_is_ready (Debugger *debugger);
 gboolean debugger_program_is_running (Debugger *debugger);
 gboolean debugger_program_is_attached (Debugger *debugger);
 gboolean debugger_program_is_loaded (Debugger *debugger);
-IAnjutaDebuggerStatus debugger_get_status (Debugger *debugger);
+IAnjutaDebuggerState debugger_get_state (Debugger *debugger);
 
 /* Send standard gdb MI2 or CLI commands */
 void debugger_command (Debugger *debugger, const gchar *command,
 					   gboolean suppress_error, DebuggerParserFunc parser,
 					   gpointer user_data);
 
-void debugger_change_location (Debugger *debugger, const gchar *file,
+void debugger_program_moved (Debugger *debugger, const gchar *file,
 							   gint line, guint address);
 gchar* debugger_get_source_path (Debugger *debugger, const gchar *file);
 
@@ -161,8 +161,8 @@ void debugger_set_frame (Debugger *debugger, guint frame);
 
 /* Thread */
 void debugger_list_thread (Debugger *debugger, IAnjutaDebuggerCallback func, gpointer user_data);
-void debugger_set_thread (Debugger *debugger, guint thread);
-void debugger_info_thread (Debugger *debugger, guint thread, IAnjutaDebuggerCallback func, gpointer user_data);
+void debugger_set_thread (Debugger *debugger, gint thread);
+void debugger_info_thread (Debugger *debugger, gint thread, IAnjutaDebuggerCallback func, gpointer user_data);
 
 /* Log */
 void debugger_set_log (Debugger *debugger, IAnjutaMessageView *view);
