@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2002, 2003  Sebastian Rittau <srittau@jroger.in-berlin.de>
- * $Id: egg-datetime.c,v 1.1 2004/09/16 15:56:18 naba Exp $
+ * $Id: egg-datetime.c 3079 2007-08-30 22:38:54Z jhs $
  *
  * Based on GnomeDateEdit by Miguel de Icaza.
  *
@@ -16,8 +16,8 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with the Gnome Library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 /****************************************************************/
 /* This file is modified for the use with gtodo. 		*/
@@ -282,8 +282,8 @@ egg_datetime_class_init (EggDateTimeClass *klass)
 
 	parent_class = g_type_class_peek_parent (klass);
 
-	o_class  = (GObjectClass *)   klass;
-	go_class = (GtkObjectClass *) klass;
+	o_class  = G_OBJECT_CLASS (klass);
+	go_class = GTK_OBJECT_CLASS (klass);
 
 	o_class->finalize     = egg_datetime_finalize;
 	o_class->set_property = egg_datetime_set_property;
