@@ -15,7 +15,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
 /*
@@ -387,7 +387,7 @@ atp_output_context_print (ATPOutputContext *this, const gchar* text)
 				g_signal_connect (G_OBJECT (this->view), "message_clicked",
 							  G_CALLBACK (on_message_buffer_click), this);
 				g_object_add_weak_pointer (G_OBJECT (this->view),
-										   (gpointer *)&this->view);
+										   (gpointer *)(gpointer)&this->view);
 			}
 			else
 			{
@@ -572,6 +572,18 @@ atp_output_context_print_result (ATPOutputContext *this, gint error)
 	return ok;
 };
 
+static IAnjutaEditor*
+get_current_editor(IAnjutaDocumentManager* docman)
+{
+	if (docman == NULL)
+		return NULL;
+	IAnjutaDocument* doc = ianjuta_document_manager_get_current_document(docman, NULL);
+	if (doc && IANJUTA_IS_EDITOR(doc))
+		return IANJUTA_EDITOR(doc);
+	else
+		return NULL;
+}
+
 static ATPOutputContext*
 atp_output_context_initialize (ATPOutputContext *this,
 							   ATPExecutionContext *execution,
@@ -591,35 +603,35 @@ atp_output_context_initialize (ATPOutputContext *this,
 		break;
 	case ATP_TOUT_REPLACE_BUFFER:
 		docman = anjuta_shell_get_interface (ANJUTA_PLUGIN (this->execution->plugin)->shell, IAnjutaDocumentManager, NULL);
-		this->editor = docman == NULL ? NULL : ianjuta_document_manager_get_current_editor (docman, NULL);
+		this->editor = get_current_editor(docman);
 		if (this->editor != NULL)
 		{
-			g_object_add_weak_pointer (G_OBJECT (this->editor), (gpointer *)&this->editor);
+			g_object_add_weak_pointer (G_OBJECT (this->editor), (gpointer *)(gpointer)&this->editor);
 			ianjuta_editor_erase_all (this->editor, NULL);
 			break;
 		}
 		/* Go through, try to create a new buffer */
 	case ATP_TOUT_NEW_BUFFER:
 		docman = anjuta_shell_get_interface (ANJUTA_PLUGIN (this->execution->plugin)->shell, IAnjutaDocumentManager, NULL);
-		this->editor = docman == NULL ? NULL : ianjuta_document_manager_add_buffer (docman, this->execution->name,"", NULL);
+		this->editor = get_current_editor(docman);
 		if (this->editor == NULL)
 		{
 			anjuta_util_dialog_warning (GTK_WINDOW (this->execution->plugin->shell), _("Unable to create a buffer, command aborted"));
 			return NULL;
 		}
-		g_object_add_weak_pointer (G_OBJECT (this->editor), (gpointer *)&this->editor);
+		g_object_add_weak_pointer (G_OBJECT (this->editor), (gpointer *)(gpointer)&this->editor);
 		break;
 	case ATP_TOUT_INSERT_BUFFER:
 	case ATP_TOUT_APPEND_BUFFER:
 	case ATP_TOUT_REPLACE_SELECTION:
 		docman = anjuta_shell_get_interface (ANJUTA_PLUGIN (this->execution->plugin)->shell, IAnjutaDocumentManager, NULL);
-		this->editor = docman == NULL ? NULL : ianjuta_document_manager_get_current_editor (docman, NULL);
+		this->editor = docman == NULL ? NULL : IANJUTA_EDITOR( ianjuta_document_manager_get_current_document (docman, NULL));
 		if (this->editor == NULL)
 		{
 			anjuta_util_dialog_warning (GTK_WINDOW (this->execution->plugin->shell), _("No document currently open, command aborted"));
 			return NULL;
 		}
-		g_object_add_weak_pointer (G_OBJECT (this->editor), (gpointer *)&this->editor);
+		g_object_add_weak_pointer (G_OBJECT (this->editor), (gpointer *)(gpointer)&this->editor);
 		this->position = ianjuta_editor_get_position (this->editor, NULL);
 		/* No break, need a buffer too */
 	case ATP_TOUT_POPUP_DIALOG:
@@ -962,7 +974,7 @@ atp_user_tool_execute (GtkMenuItem *item, ATPUserTool* this)
 		case ATP_TIN_BUFFER:
 			docman = anjuta_shell_get_interface (ANJUTA_PLUGIN (plugin)->shell,
 												 IAnjutaDocumentManager, NULL);
-			ed = docman == NULL ? NULL : ianjuta_document_manager_get_current_editor (docman, NULL);
+			ed = get_current_editor(docman);
 			if (ed != NULL)
 			{
 				input = ianjuta_editor_get_text (ed, 0, -1, NULL);
@@ -971,7 +983,7 @@ atp_user_tool_execute (GtkMenuItem *item, ATPUserTool* this)
 		case ATP_TIN_SELECTION:
 			docman = anjuta_shell_get_interface (ANJUTA_PLUGIN (plugin)->shell,
 												 IAnjutaDocumentManager, NULL);
-			ed = docman == NULL ? NULL : ianjuta_document_manager_get_current_editor (docman, NULL);
+			ed = get_current_editor(docman);
 			if (ed != NULL)
 			{
 				input = ianjuta_editor_selection_get (IANJUTA_EDITOR_SELECTION (ed),
